@@ -1,4 +1,8 @@
 """mlops is a package for conducting MLOps, including versioning of datasets and
 models."""
 
-__version__ = '0.0.2'
+__version__ = '0.0.4'
+
+from . import dataset
+from . import errors
+from . import model
